You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2019/10/10 07:07:48 UTC

[camel-quarkus] 01/06: Fixes #45 to update the extensions list in the website docs also.

This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch fix245
in repository https://gitbox.apache.org/repos/asf/camel-quarkus.git

commit aef16d1e8c74abdfc434c11e9c2de92a0cdb1367
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Wed Oct 9 12:20:43 2019 +0200

    Fixes #45 to update the extensions list in the website docs also.
---
 catalog/camel-quarkus-catalog/pom.xml                 |  4 ++--
 extensions/readme.adoc                                |  6 +++---
 ...admeMojo.java => UpdateDocExtensionsListMojo.java} | 19 ++++++++++++-------
 3 files changed, 17 insertions(+), 12 deletions(-)

diff --git a/catalog/camel-quarkus-catalog/pom.xml b/catalog/camel-quarkus-catalog/pom.xml
index 7ce0e6e..d497e6d 100644
--- a/catalog/camel-quarkus-catalog/pom.xml
+++ b/catalog/camel-quarkus-catalog/pom.xml
@@ -86,10 +86,10 @@
                 </dependencies>
                 <executions>
                     <execution>
-                        <!-- prepare the catalog, readme files, etc. -->
+                        <!-- prepare the catalog and update doc files, etc. -->
                         <goals>
                             <goal>prepare-catalog-quarkus</goal>
-                            <goal>prepare-extensions-readme</goal>
+                            <goal>update-doc-extensions-list</goal>
                         </goals>
                         <phase>process-resources</phase>
                     </execution>
diff --git a/extensions/readme.adoc b/extensions/readme.adoc
index c73ff15..8fee6ec 100644
--- a/extensions/readme.adoc
+++ b/extensions/readme.adoc
@@ -92,7 +92,7 @@ Number of Camel data formats: 3 in 3 JAR artifacts (0 deprecated)
 
 | link:https://camel.apache.org/components/latest/csv-dataformat.html[CSV] (camel-quarkus-csv) | 0.2 | The CSV data format is used for handling CSV payloads.
 
-| link:https://camel.apache.org/components/latest/mime-multipart-dataformat.html[MIME Multipart] (camel-quarkus-mail) | 0.2 | The MIME Multipart data format can marshal a Camel message with attachments into a Camel message having a MIME-Multipart message as message body (and no attachments), and vise-versa when unmarshalling.
+| link:https://camel.apache.org/components/latest/mime-multipart-dataformat.html[MIME Multipart] (camel-quarkus-mail) | 0.2 | The MIME Multipart data format is used for marshalling Camel messages with attachments into MIME-Multipart message, and vise-versa.
 
 | link:https://camel.apache.org/components/latest/zipfile-dataformat.html[Zip File] (camel-quarkus-zipfile) | 0.2 | The Zip File data format is a message compression and de-compression format of zip files.
 |===
@@ -110,11 +110,11 @@ Number of Camel languages: 8 in 2 JAR artifacts (0 deprecated)
 
 | link:https://camel.apache.org/components/latest/bean-language.html[Bean method] (camel-quarkus-bean) | 0.2 | To use a Java bean (aka method call) in Camel expressions or predicates.
 
-| link:https://camel.apache.org/components/latest/constant-language.html[Constant] (camel-quarkus-core) | 0.2 | To use a constant value in Camel expressions or predicates. Important: this is a fixed constant value that is only set once during starting up the route, do not use this if you want dynamic values during routing.
+| link:https://camel.apache.org/components/latest/constant-language.html[Constant] (camel-quarkus-core) | 0.2 | To use a constant value in Camel expressions or predicates.
 
 | link:https://camel.apache.org/components/latest/exchangeProperty-language.html[ExchangeProperty] (camel-quarkus-core) | 0.2 | To use a Camel Exchange property in expressions or predicates.
 
-| link:https://camel.apache.org/components/latest/file-language.html[File] (camel-quarkus-core) | 0.2 | For expressions and predicates using the file/simple language
+| link:https://camel.apache.org/components/latest/file-language.html[File] (camel-quarkus-core) | 0.2 | For expressions and predicates using the file/simple language.
 
 | link:https://camel.apache.org/components/latest/header-language.html[Header] (camel-quarkus-core) | 0.2 | To use a Camel Message header in expressions or predicates.
 
diff --git a/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/PrepareExtensionsReadmeMojo.java b/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
similarity index 97%
rename from tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/PrepareExtensionsReadmeMojo.java
rename to tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
index e9ee00a..0cf24b4 100644
--- a/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/PrepareExtensionsReadmeMojo.java
+++ b/tooling/maven/package-maven-plugin/src/main/java/org/apache/camel/quarkus/maven/UpdateDocExtensionsListMojo.java
@@ -48,10 +48,15 @@ import static org.apache.camel.quarkus.maven.PackageHelper.loadText;
 import static org.apache.camel.quarkus.maven.PackageHelper.writeText;
 
 /**
  * Prepares the extensions/readme.adoc files content up to date with all the extensions that Apache Camel Quarkus ships.
  */
-@Mojo(name = "prepare-extensions-readme", threadSafe = true)
-public class PrepareExtensionsReadmeMojo extends AbstractMojo {
+@Mojo(name = "update-doc-extensions-list", threadSafe = true)
+public class UpdateDocExtensionsListMojo extends AbstractMojo {
 
     /**
      * The maven project.
@@ -365,7 +370,7 @@ public class PrepareExtensionsReadmeMojo extends AbstractMojo {
 
     private String templateComponents(List<ComponentModel> models, int artifacts, long deprecated) throws MojoExecutionException {
         try {
-            String template = loadText(PrepareExtensionsReadmeMojo.class.getClassLoader().getResourceAsStream("readme-components.mvel"));
+            String template = loadText(UpdateDocExtensionsListMojo.class.getClassLoader().getResourceAsStream("readme-components.mvel"));
             Map<String, Object> map = new HashMap<>();
             map.put("components", models);
             map.put("numberOfArtifacts", artifacts);
@@ -379,7 +384,7 @@ public class PrepareExtensionsReadmeMojo extends AbstractMojo {
 
     private String templateOthers(List<OtherModel> models, int artifacts, long deprecated) throws MojoExecutionException {
         try {
-            String template = loadText(PrepareExtensionsReadmeMojo.class.getClassLoader().getResourceAsStream("readme-others.mvel"));
+            String template = loadText(UpdateDocExtensionsListMojo.class.getClassLoader().getResourceAsStream("readme-others.mvel"));
             Map<String, Object> map = new HashMap<>();
             map.put("others", models);
             map.put("numberOfArtifacts", artifacts);
@@ -393,7 +398,7 @@ public class PrepareExtensionsReadmeMojo extends AbstractMojo {
 
     private String templateDataFormats(List<DataFormatModel> models, int artifacts, long deprecated) throws MojoExecutionException {
         try {
-            String template = loadText(PrepareExtensionsReadmeMojo.class.getClassLoader().getResourceAsStream("readme-dataformats.mvel"));
+            String template = loadText(UpdateDocExtensionsListMojo.class.getClassLoader().getResourceAsStream("readme-dataformats.mvel"));
             Map<String, Object> map = new HashMap<>();
             map.put("dataformats", models);
             map.put("numberOfArtifacts", artifacts);
@@ -407,7 +412,7 @@ public class PrepareExtensionsReadmeMojo extends AbstractMojo {
 
     private String templateLanguages(List<LanguageModel> models, int artifacts, long deprecated) throws MojoExecutionException {
         try {
-            String template = loadText(PrepareExtensionsReadmeMojo.class.getClassLoader().getResourceAsStream("readme-languages.mvel"));
+            String template = loadText(UpdateDocExtensionsListMojo.class.getClassLoader().getResourceAsStream("readme-languages.mvel"));
             Map<String, Object> map = new HashMap<>();
             map.put("languages", models);
             map.put("numberOfArtifacts", artifacts);
@@ -48,10 +48,15 @@ import static org.apache.camel.quarkus.maven.PackageHelper.loadText;
 
 /**
- * Prepares the extensions/readme.adoc files content up to date with all the extensions that Apache Camel Quarkus ships.
+ * Updates the documentation in:
+ *
+ * - extensions/readme.adoc
+ * - docs/modules/ROOT/pages/list-of-camel-quarkus-extensions.adoc
+ *
+ * to be up to date with all the extensions that Apache Camel Quarkus ships.
  */